"""
Simple nose plugin to allow a user to chain additional directories onto
their pythonpath.
"""

from nose.plugins.base import Plugin
import os
import sys

class PathMunge(Plugin):

    enabled = False
    name = "pathmunge"
    score = 3
    env_opt = "NOSE_ADDITIONAL_PATHS"
    def options(self, parser, env=os.environ):
        """ Define the command line options for the plugin. """
        parser.add_option(
            "--with-path", action="append",
            dest="additional_paths",
            help="Additional directories to add to the nose sys.path [NOSE_ADDITIONAL_PATHS]")

    def configure(self, options, noseconfig):
        """ Call the super and then validate and call the relevant parser for
        the configuration file passed in """
        if not options.additional_paths:
            self.enabled = False
            return
        Plugin.configure(self, options, noseconfig)

        all_paths = []
        for path in options.additional_paths:
            if len(path.split(',')) > 1:
                all_paths.extend(path.split(','))
            else:
                all_paths.append(path)
        for path in all_paths:
            path = os.path.expanduser(path)
            path = os.path.abspath(path)
            if not os.path.isdir(path):
                raise Exception('%s is not a directory' % path)
        sys.path.extend([path for path in all_paths])



import os
import sys
try:
    import ez_setup
    ez_setup.use_setuptools()
except ImportError:
    pass
from setuptools import setup

# Use a cute trick to include the rest-style docs as the long_description
# therefore having it self-doc'ed and hosted on pypi
f = open(os.path.join(os.path.dirname(__file__), 'README.txt'))
long_description = f.read().strip()
f.close()

setup(
    name='nose-pathmunge',
    version='0.1.2',
    author='Jesse Noller',
    author_email = 'jnoller@gmail.com',
    description = 'Add additional directories to sys.path for nose.',
    long_description = long_description,
    license = 'Apache License, Version 2.0',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: Software Development :: Testing',
      ],
    py_modules=['pathmunge'],
    packages=[''],
    package_dir={'': 'src'},
    package_data = {'': ['README.txt']},
    entry_points = {
        'nose.plugins.0.10': [
            'pathmunge = pathmunge:PathMunge',
            ]
        }
    )
